@@ -2,25 +2,28 @@ context("Fitting 'vinecop' models")
 
 set.seed(5)
 u <- sapply(1:5, function(i) runif(30))
-fit <- vinecop(u, "nonpar")
-fit_with_data <- vinecop(u, "nonpar", keep_data = TRUE)
+fit <- vinecop(u, family = "nonpar")
+fit_with_data <- vinecop(u, family = "nonpar", keep_data = TRUE)
 
 test_that("returns proper 'vinecop' object", {
   expect_s3_class(fit, "vinecop")
   expect_s3_class(fit, "vinecop_dist")
   expect_identical(
     names(fit),
-    c("pair_copulas", "structure", "npars", "loglik", "threshold", "controls", "nobs")
+    c("pair_copulas", "structure", "var_types",
+      "npars", "loglik", "threshold", "controls", "nobs")
   )
   expect_identical(
     names(fit_with_data),
-    c("pair_copulas", "structure", "npars", "loglik", "threshold", "data", "controls", "nobs")
+    c("pair_copulas", "structure", "var_types",
+      "npars", "loglik", "threshold", "data", "controls", "nobs")
   )
 
   colnames(u) <- paste(seq_len(ncol(u)))
   expect_identical(
-    names(vinecop(u, "indep")),
-    c("pair_copulas", "structure", "npars", "loglik", "threshold", "names", "controls", "nobs")
+    names(vinecop(u, family = "indep")),
+    c("pair_copulas", "structure", "var_types",
+      "npars", "loglik", "threshold", "names", "controls", "nobs")
   )
 })
 
@@ -57,7 +60,20 @@ test_that("truncation works", {
   expect_silent(dvinecop(u, fit_truncated))
   expect_silent(rvinecop(50, fit_truncated))
 
-  fit_truncated <- vinecop(u, "par", trunc_lvl = 1)
+  fit_truncated <- vinecop(u, family = "par", trunc_lvl = 1)
   expect_silent(dvinecop(u, fit_truncated))
   expect_silent(rvinecop(50, fit_truncated))
 })
+
+test_that("partial selection works", {
+  fit_partial <- vinecop(u[, sample(1:5)],
+                         structure = truncate_model(fit$structure, 1),
+                         trunc_lvl = 3)
+  expect_equal(unname(dim(fit_partial)[2]), 3)
+
+  m_old <- as_rvine_matrix(fit$structure)
+  m_new <- as_rvine_matrix(fit_partial$structure)
+  tree1_old_edges <- c(paste(diag(m_old[5:2, ]), m_old[1, -5]),
+                       paste(m_old[1, -5], diag(m_old[5:2, ])))
+  expect_true(all(paste(diag(m_new[5:2, ]), m_new[1, -5]) %in% tree1_old_edges))
+})
